## ecr.types

src/ecr/types.py
    1
    2
    3
    4
    5
    6
    7
    8
    9
    10
    11
    12
    13
    from typing import Callable, Dict, List, Optional

    CommandList = List[str]

    ExecutorMapping = Dict[str, CommandList]

    JudgerMapping = Dict[str, CommandList]

    CommandMapping = Dict[str, str]

    CodeTemplateMapping = Dict[str, str]

    VariableMapping = Dict[str, Callable[[], Optional[str]]]